@@ -8,7 +8,7 @@ use Path::Tiny ();
 
 use Moo;
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 # todo, type checking?
 
@@ -71,7 +71,7 @@ sub remove {
 
 sub _sig {
     my ( $self, $data ) = @_;
-    return sha1_hex( join( ",", @$data ) );
+    return sha1_hex( join( ',', @$data ) );
 }
 
 1;
@@ -90,17 +90,17 @@ Code::TidyAll::CacheModel - Caching model for Code::TidyAll
 
 =head1 VERSION
 
-version 0.58
+version 0.59
 
 =head1 SYNOPSIS
 
   my $cache_model = Cody::TidyAll::CacheModel->new(
       cache_engine => Code::TidyAll::Cache->new(...),
-      path         => "/path/to/file/to/cache",
+      path         => '/path/to/file/to/cache',
   );
 
   # check cache
-  print "Yes!" if $cache_model->is_cached;
+  print 'Yes!' if $cache_model->is_cached;
 
   # update cache
   $cache_model->clear_file_contents;
