@@ -8,7 +8,7 @@ use IPC::System::Simple qw(capturex);
 
 use Exporter qw(import);
 
-our $VERSION = '0.58';
+our $VERSION = '0.59';
 
 our @EXPORT_OK = qw(svn_uncommitted_files);
 
@@ -16,7 +16,7 @@ sub svn_uncommitted_files {
     my ($dir) = @_;
 
     $dir = realpath($dir);
-    my $output = capturex( "svn", "status", $dir );
+    my $output = capturex( 'svn', 'status', $dir );
     my @lines = grep {/^[AM]/} split( "\n", $output );
     my (@files) = grep {-f} ( $output =~ m{^[AM]\s+(.*)$}gm );
     return @files;
