@@ -15,12 +15,12 @@ sub test_main : Tests {
     );
     $self->tidyall(
         source      => $source,
-        conf        => { argv => '-m 1 --perltidy-argv="-pt=2 -i=3"' },
+        conf        => { argv => q{-m 1 --perltidy-argv="-pt=2 -i=3"} },
         expect_tidy => '% if ($foo) {\n%    bar(1, 2);\n% }'
     );
     $self->tidyall(
         source      => $source,
-        conf        => { argv => '-m 2 --perltidy-line-argv=" "' },
+        conf        => { argv => q{-m 2 --perltidy-line-argv=" "} },
         expect_tidy => '% if ($foo) {\n%     bar( 1, 2 );\n% }'
     );
     $self->tidyall(
